@@ -1,16 +1,18 @@
 import json
 from typing import Any
 
-from sanic.exceptions import abort
+from sanic.exceptions import ServerError, abort
 from sanic.request import Request
 from sanic.response import HTTPResponse, html
 from sanic.views import HTTPMethodView
+from strawberry.file_uploads.data import replace_placeholders_with_files
 from strawberry.http import GraphQLHTTPResponse, process_result
-from strawberry.types import ExecutionResult
+from strawberry.types import ExecutionContext, ExecutionResult
 
 from ..schema import BaseSchema
 from .context import StrawberrySanicContext
 from .graphiql import render_graphiql_page
+from .utils import convert_request_to_files_dict
 
 
 class GraphQLView(HTTPMethodView):
@@ -62,22 +64,16 @@ class GraphQLView(HTTPMethodView):
             template = render_graphiql_page()
             return self.render_template(template=template)
 
-        data = request.json
-        try:
-            query = data["query"]
-        except KeyError:
-            return HTTPResponse("No valid query was provided for the request", 400)
-
-        variables = data.get("variables")
-        operation_name = data.get("operationName")
+        operation_context = self.get_execution_context(request)
         context = await self.get_context(request)
+        root_value = self.get_root_value()
 
         result = await self.schema.execute(
-            query,
-            variable_values=variables,
+            query=operation_context.query,
+            variable_values=operation_context.variables,
             context_value=context,
-            operation_name=operation_name,
-            root_value=self.get_root_value(),
+            root_value=root_value,
+            operation_name=operation_context.operation_name,
         )
         response_data = self.process_result(result)
 
@@ -85,6 +81,35 @@ class GraphQLView(HTTPMethodView):
             json.dumps(response_data), status=200, content_type="application/json"
         )
 
+    def get_execution_context(self, request: Request) -> ExecutionContext:
+        try:
+            data = self.parse_body(request)
+        except json.JSONDecodeError:
+            raise ServerError("Unable to parse request body as JSON", status_code=400)
+
+        try:
+            query = data["query"]
+        except KeyError:
+            raise ServerError("No GraphQL query found in the request", status_code=400)
+
+        variables = data.get("variables")
+        operation_name = data.get("operationName")
+
+        return ExecutionContext(
+            query=query, variables=variables, operation_name=operation_name
+        )
+
+    def parse_body(self, request: Request) -> dict:
+        if request.content_type.startswith("multipart/form-data"):
+            files = convert_request_to_files_dict(request)
+            operations = json.loads(request.form.get("operations", "{}"))
+            files_map = json.loads(request.form.get("map", "{}"))
+            try:
+                return replace_placeholders_with_files(operations, files_map, files)
+            except KeyError:
+                abort(400, "File(s) missing in form data")
+        return request.json
+
     def should_display_graphiql(self, request):
         if not self.graphiql:
             return False
